# Uniformly Weighted LASSO type quantile regression at a given quantile vector with BIC tuning parameter selector
#'@export
grqalasso=function(y,x,tau=c(0.1,0.9), method="BC", weights="unif", grid=seq(0, nrow(x)/20, length.out=nrow(x)/4), tol=1e-10){
  if (length(tau)%%2!=0) {
    return ("Error, the length of tau must be an even number");
  }
  if ( prod(tau==sort(tau))==0) {
    return ("Error, tau must be in an increasing order");
  }

  #### the tau grid for the quantile interval of interest
  ap_tau=seq(0,1,length.out=n/2);                           #  all equally spaced taus from 0 and 1 with length n/2
  Ind=NULL;                                     
  for( i in 1:(length(tau)/2)){ 
    Ind=c(Ind, intersect( which(ap_tau>=tau[2*i-1]),which(ap_tau<=tau[2*i])));
  }
  if (length(Ind)==0){
    return ("Error, please specify a larger set");
  } 
  J=ap_tau[Ind];    
  obj=vecrqalasso(y,x,taus=J, method, weights, grid, tol);
  return (obj)
}