# 5-fold CV to find the tuning parameter for the initial estimator
#'@export

lambdaCV=function(y,x,taus, K=5, len=2*sqrt(nrow(x)), tol=1e-10){
  require(quantreg);
  pp=ncol(x);                           # Dimensionality
  nn=nrow(x);                           # sample size
  tol=1e-10;
  
  size <- (nn) %/% K;
  rdm <- runif(nn);
  ranked <- rank(rdm);
  block <- (ranked-1) %/% size+1;
  block <- as.factor(block);
  
  
  comp=Inf;                             # Cross-Validation store
  count=0;					                    # 	
  ptr1=0;                               # the smallest CV
  ptr2=0;          				              # the second smallest CV
  Ada=TRUE;
  ka=1/2;
  init_lam=NULL; 
  init_cv=NULL;
  while(Ada){
    ka=ka*2;
    count=count+1;
    init_lam=c(init_lam,ka);
    tmpb=coef(rq(y~0+x,method="lasso",tau=taus,lambda=rep(ka,pp)));
    if(sum(abs(tmpb[-1]))<=tol){Ada=FALSE;}
    
    testerr=rep(0,K);
    for (k in 1:K) {
      xT=x[block!=k,]; yT=y[block!=k];
      xP=x[block==k,]; yP=y[block==k];
      
      fitb=coef(rq(yT~0+xT,method="lasso",tau=taus,lambda=rep(ka,pp)));
      fitb=fitb*(abs(fitb)>=tol);
      err= replicate(length(taus), as.vector(yP))-xP%*%fitb;
      
      tmptesterr=rep(0,length(taus));
      for(s in 1:length(taus)){
        tmptesterr[s]=sum((err[,s]>0)*taus[s]*err[,s]-(1-taus[s])*(err[,s]<0)*err[,s]);
      }
      testerr[k]=sum(tmptesterr);
    }
    
    cv_testerr=sum(testerr);
    init_cv=c(init_cv,cv_testerr);
    if (cv_testerr< comp) {
      comp=cv_testerr; 
      ptr2=ptr1;
      ptr1=count;
    }
  }
  #### 2nd search ( a finer one)
  ## construct a CV grid
  gL=min(ptr1,ptr2);             gU=max(ptr1,ptr2);
  if(gL==1) {gL=2;}              
  gridL=max(init_lam[1], init_lam[gL-1]);
  if(gU==count) {gU=count-1;}    
  gridU=min(init_lam[count], init_lam[gU+1]);
  
  lam=seq(gridL, gridU,length.out=len);
  cv1=rep(0,len);
  for (i in 1: len){
    ka=lam[i];
    testerr=rep(0,K);
    for (k in 1:K) {
      xT=x[block!=k,];
      xP=x[block==k,];
      yT=y[block!=k];
      yP=y[block==k];
      
      fitb=coef(rq(yT~0+xT,method="lasso",tau=taus,lambda=rep(ka,pp)));
      fitb=fitb*(abs(fitb)>=tol);
      err= replicate(length(taus), as.vector(yP))-xP%*%fitb;
      tmptesterr=rep(0,length(taus));
      for(s in 1:length(taus)){
        tmptesterr[s]=sum((err[,s]>0)*taus[s]*err[,s]-(1-taus[s])*(err[,s]<0)*err[,s]);
      }
      testerr[k]=sum(tmptesterr);
    }
    cv1[i]=sum(testerr);
  }
  step.cv1=which.min(cv1);  
  return(lam[step.cv1]);
}