\name{grqalasso}
\alias{grqalasso}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
GIC type tuning parameter selector for globally adaptive quantile regression 
}
\description{
This is a functon to select a tuning parameter for globally adaptive quantile quantile based on the GIC criterion proposed by Zheng, Peng and He (2015).
}
\usage{
grqalasso(y,x,tau=c(0.1,0.9), method="BC", weights="unif",grid=seq(0, nrow(x)/20, length.out=nrow(x)/4), tol=1e-10)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{y}{
  The response  vector.
}
  \item{x}{
  The covariates matrix.
}
  \item{tau}{
  The quantile interval of interest. The default is [0.1, 0.9].
}
  \item{method}{
  The method to obtain the tuning parameter for the high dimensional Lasso-type estimator. 
  The default is "BC", which adopts the tuning parameter selector proposed by Belloni and Chernozhukov (2011).  The other option is "CV5", which selects the tuning parameter by 5-fold Cross Validation.
}
  \item{weights}{
  The type of adaptive weights. There are three different types: "unif", "absmean", and "pointwise". The default is "unif", which calculate the adaptive weights according to the infinity norm of quantile coefficient, and adaptive weights are the same at all given quantile levels.  The  "absmean" penalties  measure the L1 norm of quantile coefficients. The third type pointwise" are the ordinary adaptive lasso penalties, and vary across taus.
}

\item{grid}{
  The GIC grid. The default is of n/4 equally spaced points from 0 to n/20.
}

  \item{tol}{
  Tolerance, the default is 1e-10.
}
}
\details{
The function first choose the quantile levels needed in the given region, and then it will call the function verrqalasso().
}
\value{
The function returns a list containing
  \item{taus }{all quantile levels considered in the given region}
  \item{estbeta }{the corresponding solutions at the given quantiles}
  \item{lambda.cv}{tuning parameter for the Lasso-type estimator}
  \item{lambda.gic}{tuning parameter for the globally adaptive quantile regression}
  \item{method}{the method used to select lambda.cv: either "BC" or "CV5"}
  \item{weights}{the adaptive weights used: "unif", "absmean" or "pointwise"}
%% ...
}
\references{
Zheng et al (2015, Annals of Statistics) Globally adaptive quantile regression with ultra-high dimensional data.
}
\author{
Qi Zheng (zheng.qi85@gmail.com)
}
\note{
If the option "CV5" is specified, the procedure may be time-consuming. (We are developing a faster CV version)
}

%% ~Make other sections like Warning with \section{Warning }{....} ~

%\seealso{
%% ~~objects to See Also as \code{\link{help}}, ~~~
%}
\examples{
library(MASS)
library(quantreg)

p=400;                                            ######## model dim
n=200;                                            ######## sample size

######## covariance matrix
Sigma=matrix(0,p,p);                           
pho=0.5;
J=seq(1,p,1);
for (i in 1:p){Sigma[i,]=pho^(abs(i-J))};

######## covariate matrix
Z=mvrnorm(n=n , rep(0,p), Sigma,  empirical = FALSE); ######## Generate covariates
X=cbind(rep(1,n),Z);                                  ######## Add intercept 
########################################################

######## regression coefficients
beta=rep(0,p+1);
beta[2]=2;  beta[3]=1.5;   beta[6]=3; beta[9]=1;  beta[13]=0.9;  beta[17]=1;

######## errors and response variable
epsilon=rnorm(n,0,sqrt(2));                           quantile
Y=X\%*\%beta+epsilon;

object=grqalasso(Y,Z,tau=c(0.2,0.8),method="BC", weights="absmean")
}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{ Quantile region }
\keyword{ GIC }% __ONLY ONE__ keyword per line
