\name{lambdaCV}
\alias{lambdaCV}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
Tuning parameter selector for the globally Lasso type quantile regression based on 5-fold cross validation
}
\description{
This is a functon to select a tuning parameter for the Lasso type  estimator  based on the 5-fold cross-validation. The Lasso type estimator will be used to construct the adaptive penalities for the globally adaptive quantile quantile proposed by Zheng, Peng and He (2015).
}
\usage{
lambdaCV(y, x, taus, K=5, len = 2 * sqrt(nrow(x)), tol=1e-10)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{y}{
  The response  vector.
}
  \item{x}{
  The covariates matrix. 
}
  \item{taus}{
  The tau grid between 0 and 1.
}
  \item{K}{
  The K-fold cross-validation, and the default is 5.
}
  \item{len}{
  The number of grid points for Cross-Validation. The default is 2 * sqrt(nrow(x)).
}
  \item{tol}{
  Tolerance, the default is 1e-10.
}
}
\details{
1. Two-layer Cross-Validation search are included: (Step 1): the initial search is conducted on the grid \{ 1, 2, 4, \dots\} until  the estimated coeffs are small enough.   (Step 2): the next search will conducted around two grid points with the smallest CV value from (Step 1).  It can be seen as a refined CV search. The new grid is of legnth len.
}
\value{
The function returns the selected tuning parameter. 
}
%\references{}
\author{
Qi Zheng (zheng.qi85@gmail.com)
}
\note{
This procedure is time-consuming for ultra-high dimensional data, especially in step 1. 
(We are developing a faster CV version)
}

%% ~Make other sections like Warning with \section{Warning }{....} ~

%\seealso{
%% ~~objects to See Also as \code{\link{help}}, ~~~
%}
\examples{
library(MASS)
library(quantreg)

p=400;                                            ######## model dim
n=200;                                            ######## sample size

######## covariance matrix
Sigma=matrix(0,p,p);                           
pho=0.5;
J=seq(1,p,1);
for (i in 1:p){Sigma[i,]=pho^(abs(i-J))};

######## covariate matrix
Z=mvrnorm(n=n , rep(0,p), Sigma,  empirical = FALSE); ######## Generate covariates
Z=pnorm(Z);
for(i in 1:p){
        Z[,i]=Z[,i]/sqrt(sum(Z[,i]^2)/n);
}
X=cbind(rep(1,n),Z);

######## regression coefficients
alpha=rep(0,p+1);
alpha[2]=2;
alpha[3]=1.5;
gamma=rep(0,p+1);
gamma[9]=2;

######## errors and response variable
epsilon=rnorm(n);                         
Y=X\%*\%alpha+(X\%*\%gamma)*epsilon;

######## taus grid
tauL=0.3;
tauU=0.7;
J=seq(tauL,tauU,0.01);                  

lambda=lambdaCV(Y,X,J);
}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{ ~kwd1 }
\keyword{ ~kwd2 }% __ONLY ONE__ keyword per line
