\name{lambdaGIC}
\alias{lambdaGIC}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
GIC type tuning parameter selector for globally adaptive quantile regression 
}
\description{
This is a functon to select a tuning parameter for globally adaptive quantile quantile based on the GIC criterion proposed by Zheng, Peng and He (2015).
}
\usage{
lambdaGIC(y, x, tau, w, grid=seq(0, nrow(x)/20, length.out=nrow(x)/4), tol=1e-10)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{y}{
  The response  vector.
}
  \item{x}{
  The covariates matrix.
}
  \item{tau}{
  The tau grid between 0 and 1.
}
  \item{w}{
  The adaptive penalties.
}
  \item{grid}{
  The GIC grid. The default is of n/4 equally spaced points from 0 to n/20.
}
  \item{tol}{
  Tolerance, the default is 1e-10.
}
}
\details{
The GIC is calculated at the given tau grid. If tau is a single quantile, it reduces to the GIC proposed by Fan and Tang (2013); otherwise, If tau is a vector of quantile, then the globally GIC  (Zheng et al, 2015) will be implmented at the specified quantile levels.
}
\value{
The function returns the selected tuning parameter for globally adaptive quantile regression.
}
\references{
Fan, Y, and Tang, C. (2013, Journal of Royal Statistical Society, B.) Tuning parameter slection in high dimensional penalized likelihood. 

Zheng et al (2015, Annals of Statistics) Globally adaptive quantile regression with ultra-high dimensional data.
}
\author{
Qi Zheng (zheng.qi85@gmail.com)
}
\note{
This procedure requires standardized response and covariates.
}

%% ~Make other sections like Warning with \section{Warning }{....} ~

%\seealso{
%% ~~objects to See Also as \code{\link{help}}, ~~~
%}
\examples{
library(quantreg)
library(flare)
data(eyedata)

######## data information
p=dim(x)[2];
n=length(y);

######## standardize data
meany=mean(y);
Y=y-meany;    
normy=sqrt(mean(Y^2));
Y=Y/normy;
  
meanx=apply(x,2,mean);
X=x-outer(rep(1,dim(x)[1]),meanx);
normx=sqrt(apply(X^2,2,mean));
X=sweep(X,2,1/normx,"*");
X=cbind(rep(1,n),X);

######## quantile interval of interest
tauL=0.2;
tauU=0.8;
taus=seq(tauL,tauU,0.005); 
tol=1e-10;

######## Lasso type estimator (initial estimator)
lambda=12;
lambda1=c(0,rep(lambda,p))
fitb=coef(rq(Y~0+X,method="lasso",tau=taus,lambda=lambda1));
Estimate=t(fitb*(abs(fitb)>=tol));

######## unif weights
Pilot=1/abs(Estimate);          
Pilot[which(Pilot==Inf)]=1e+50;                   
unifwt=apply(Pilot,2,min);

lambda.gic=lambdaGIC(Y,X,tau=taus,w=unifwt);
}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{ GIC }
\keyword{Globally adaptive}
\keyword{ Quantile regression }% __ONLY ONE__ keyword per line
