\name{vecrqalasso}
\alias{vecrqalasso}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
Globally adaptive quantile regression at a given quantile vector.
}
\description{
This is a functon to conduct globally adaptive quantile regression at a given quantile vector based on the proposed method in Zheng, Peng and He (2015).
}
\usage{
vecrqalasso(y,x,taus, method="BC", weights="unif",  grid=seq(0,nrow(x)/20, length.out=nrow(X)/4), tol=1e-6)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{y}{
  The response  vector.
}
  \item{x}{
  The covariates matrix.
}
  \item{taus}{
  The tau grid between 0 and 1.
}
  \item{method}{
  The method to obtain the tuning parameter for the high dimensional Lasso-type estimator. 
  The default is "BC", which adopts the tuning parameter selector proposed by Belloni and Chernozhukov (2011).  The other option is "CV5", which selects the tuning parameter by 5-fold Cross Validation.
}
  \item{weights}{
  The type of adaptive weights. There are three different types: "unif", "absmean", and "pointwise". The default is "unif", which calculate the adaptive weights according to the infinity norm of quantile coefficient, and adaptive weights are the same at all given quantile levels.  The  "absmean" penalties  measure the weighted L1 norm of quantile coefficients. 
  The third type pointwise" are the ordinary adaptive lasso penalties, and vary across taus.
}
  \item{grid}{
  The grid for GIC. The default is of n/4 equally spaced points from 0 to n/20.  
}

  \item{tol}{
  Tolerance, the default is 1e-10.
}
}
\details{
1. The data will be standardized.

2. On the first stage, it  implements a global Lasso-type quantile regression to obtain the initial estimator, from which the adaptive Lasso penalties are calculated.  The tuning parameter can be 
 
3. On the second stage, the adaptive Lasso quantile regression will be applied at the quantile vector with a uniform tuning parameter selected by a global GIC type selector.
}
\value{
The function returns a list containing

  \item{taus }{all quantile levels provided}
  \item{estbeta }{the corresponding solutions at the given quantiles}
  \item{lambda.cv}{tuning parameter for the Lasso-type estimator}
  \item{lambda.gic}{tuning parameter for the globally adaptive quantile regression}
  \item{method}{the method used to select lambda.cv: either "BC" or "CV5"}
  \item{weights}{the adaptive weights used: "unif", "absmean" or "pointwise"}
%% ...
}
\references{
Zheng et al (2015, Annals of Statistics) Globally adaptive quantile regression with ultra-high dimensional data.
}
\author{
Qi Zheng (zheng.qi85@gmail.com)
}
\note{
If the option "CV5" is specified, the procedure may be time-consuming. (We are developing a faster CV version).
}

%% ~Make other sections like Warning with \section{Warning }{....} ~

%\seealso{
%% ~~objects to See Also as \code{\link{help}}, ~~~
%}
\examples{
library(MASS)
library(quantreg)

p=400;                                            ######## model dim
n=200;                                            ######## sample size

######## covariance matrix
Sigma=matrix(0,p,p);                           
pho=0.5;
J=seq(1,p,1);
for (i in 1:p){Sigma[i,]=pho^(abs(i-J))};

######## covariate matrix
Z=mvrnorm(n=n , rep(0,p), Sigma,  empirical = FALSE); ######## Generate covariates
Z=pnorm(Z);
for(i in 1:p){
        Z[,i]=Z[,i]/sqrt(sum(Z[,i]^2)/n);
}
X=cbind(rep(1,n),Z);

######## regression coefficients
alpha=rep(0,p+1);
alpha[2]=2;
alpha[3]=1.5;
gamma=rep(0,p+1);
gamma[9]=2;

######## errors and response variable
epsilon=rnorm(n);                         
Y=X\%*\%alpha+(X\%*\%gamma)*epsilon;

######## taus grid
tauL=0.1;
tauU=0.9;
J=seq(tauL,tauU,0.01);                  

object=vecrqalasso(Y,Z,J);
}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{ Two stage estimator}
\keyword{ Cross-Validation }
\keyword{ GIC }% __ONLY ONE__ keyword per line
